@@ -195,12 +195,20 @@ function cmdPause() {
 }
 
 function screenTap() {
-    if (settingspanel.state == "VISIBLE" || hiscorepanel.state == "VISIBLE" || menupanel.state == "VISIBLE") {
+    if (messagecontainer.state == "VISIBLE") {
+        board.hideMessage();
+        return;
+    }
+
+    if (settingspanel.state == "VISIBLE" || hiscorepanel.state == "VISIBLE" || menupanel.state == "VISIBLE" || globalhiscorepanel.state == "VISIBLE") {
         settingspanel.state = "HIDDEN";
         hiscorepanel.state = "HIDDEN";
         menupanel.state = "HIDDEN";
+        globalhiscorepanel.state = "HIDDEN";
+
         return;
     }
+
     if (state == "NOTRUNNING" && !deadtimer.running) {
          cmdNewGame();
     } else if (state == "LIFELOST" || state == "PAUSED") {
